@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   %%NAME%% %%VERSION%%
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 open Bos_setup
@@ -506,7 +505,7 @@ let lint_opam_deps errs (opam, _, exclude) =
     >>= fun opam -> match exclude with
     | None ->
         Ok (lint_disabled @@
-            Fmt.(strf_like
+            Fmt.(str_like
                    stdout "opam dependency linting for %a" pp_path opam))
     | Some exclude ->
         let tags = Fpath.v "_tags" in
@@ -552,30 +551,14 @@ let lint ?(ignore_pkg = false) p ~dir todo =
     | 0 ->
         Logs.app (fun m -> m "%a lint@ %a %a"
                      pp_status `Ok pp_path dir
-                     (Fmt.styled_unit `Green "success") ()); 0
+                     Fmt.(styled `Green (any "success")) ()); 0
     | n ->
         Logs.app (fun m -> m "%a lint@ %a@ %a:@ %d@ errors."
                      pp_status `Fail pp_path dir
-                     (Fmt.styled_unit `Red "failure") () n); 1
+                     Fmt.(styled `Red (any "failure")) () n); 1
   in
   let p =
     if ignore_pkg then Ok (empty p) else
     pkg p >>| fun _ -> p (* verify the pkg_file exists *)
   in
   p >>= fun p -> OS.Dir.with_current dir lint p
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
